camelot.camelot.view.fifo.fifo

Package camelot :: Package camelot :: Package view :: Module fifo :: Class fifo |
[hide private]
[frames] | no frames]

# Class fifo

source code

fifo, is the actual cache containing a limited set of copies of row data so the data in fifo, is always immediately accessible to the gui thread, with zero delay as you scroll down the table view, fifo is filled and refilled with data queried from the database

the cache can be queried either by the row number or by the primary key of the object represented by the row data.

Instance Methods | [hide private]
__init__(self, max_entries) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
add_data(self, row, entity, value) | source code
delete_by_row(self, row) | source code
delete_by_entity(self, entity) Remove everything in the cache related to an entity instance returns the row at which the data was stored if the data was in the cache, return None otherwise | source code
get_data_at_row(self, row) | source code
get_row_by_entity(self, entity) | source code
get_entity_at_row(self, row) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, max_entries) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)